/*
 * extension.js
 * Gnome3 Jump to Overview Extension
 *
 * Opens the Overview when the last window on the current workspace is closed (Gnome-Shell < 3.10 behaviour)
 *
 *
 * Author: Simon Junga (simonthechipmunk@gmx.de)
 *
 *
 * This programm is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 */


//***// imports:

// main functionality
const Main = imports.ui.main;

// own imports
const Me = imports.misc.extensionUtils.getCurrentExtension();
const Prefs = Me.imports.prefs;



// define global variables
let workspaceRemoved, workspaceChanged, currentWorkspace, windowRemoved;



//***// basic extension functions

function init() {
 	// initialize preferences
	Prefs.init();
}




function enable() {
        // connect to 'workspace-switched' signal
        workspaceChanged = global.screen.connect('workspace-switched', _checkWorkspace);

}




function disable() {
        // disconnect from signals
        global.screen.disconnect(workspaceChanged);
        currentWorkspace.disconnect(windowRemoved);

}




//***// extension functions

function _checkWorkspace() {

        // disconnect former 'window-remved' signal (if any)
        if(currentWorkspace) {
        currentWorkspace.disconnect(windowRemoved);
        }
   
        // get the current workspace
        currentWorkspace = global.screen.get_active_workspace();

        // connect to window-removed on current workspace
        windowRemoved = currentWorkspace.connect('window-removed', function() { 


                // get active windows on current workspace and number of workspaces
                let windowList = currentWorkspace.list_windows();
                let activeWorkspaces = global.screen.get_n_workspaces();

                // check for "last window closed", "overview shown" and "last active workspace" if set in the preferences
                if( (windowList.length < 1 && Main.overview._shown == false && activeWorkspaces > 2 && !Prefs._getOnLastWS()) ||
			(windowList.length < 1 && Main.overview._shown == false && Prefs._getOnLastWS()) ) {
                        // show Overview
                        Main.overview.show.call(Main.overview);
                }                
	});



}

