/*
 * Preferences for the extension which will be available in the 
 * "gnome-shell-extension-prefs" tool.
 *
 * In the preferences, you can set the Server IP and Port.
 * see: https://live.gnome.org/GnomeShell/Extensions#Extension_Preferences
 *
 */

//***// imports:

// main
const Gio  = imports.gi.Gio;
const Gtk  = imports.gi.Gtk;
const Lang = imports.lang;
const Me   = imports.misc.extensionUtils.getCurrentExtension();


// define global variables
let settings = {};





//***// basic preferences functions

function init() {

    	const GioSSS = Gio.SettingsSchemaSource;

	// get the gsettings schema and path
    	let schema = Me.metadata['settings-schema'];
    	let source = GioSSS.new_from_directory(Me.dir.get_child('schemas').get_path(),
                                           GioSSS.get_default(),
                                           false);

	// load the schema
    	settings = new Gio.Settings({
        	settings_schema : source.lookup(schema, true)
    	});

	// create custom command bindings for bool and string
    	let set_boolean = Lang.bind(settings, settings.set_boolean);
    	let set_string = Lang.bind(settings, settings.set_string);

    	settings.set_boolean = function(key, value) {
        	set_boolean(key, value);
        	Gio.Settings.sync();
    	};

    	settings.set_string = function(key, value) {
        	set_string(key, value);
        	Gio.Settings.sync();
    	};

}



function buildPrefsWidget() {
// build the Gtk preferences widget
	let frame = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL, border_width: 10, margin: 20});

	// add items to the widget frame
	frame.add( _createSwitchbox("Show Overview when closing Window on last Workspace", 
		"Opens the Overview even when the current Workspace is the last one"));	
	frame.show_all();
	return frame;
}






//***// preferences functions

function _createSwitchbox(text, tooltip) {
// create box with text entry for Server IP
	let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
	let label = new Gtk.Label({ label: text, xalign: 0, tooltip_text: tooltip });
	let toggleswitch = new Gtk.Switch({ active: _getOnLastWS() });

	// connect to "toggled" emit signal
	toggleswitch.connect('notify::active', _setOnLastWS);

	//fill the box with content
	box.pack_start(label, true, true, 0);
	box.add(toggleswitch);

	return box;
}






// functions to get/set gsettings entries
function _getOnLastWS() {
	return settings.get_boolean('onlastworkspace');
}


function _setOnLastWS() {
    settings.set_boolean('onlastworkspace', !_getOnLastWS());
}



